@@ -11,21 +11,20 @@
 #include "emailaddressselection_p.h"
 
 #include <KContacts/ContactGroup>
-#include <KMime/HeaderParsing>
+#include <KMime/Types>
 
 using namespace Akonadi;
 
 EmailAddressSelectionPrivate::EmailAddressSelectionPrivate()
-
 {
 }
 
 EmailAddressSelectionPrivate::EmailAddressSelectionPrivate(const EmailAddressSelectionPrivate &other)
     : QSharedData(other)
+    , mName(other.mName)
+    , mEmailAddress(other.mEmailAddress)
+    , mItem(other.mItem)
 {
-    mName = other.mName;
-    mEmailAddress = other.mEmailAddress;
-    mItem = other.mItem;
 }
 
 EmailAddressSelection::EmailAddressSelection()
