@@ -8,7 +8,7 @@
 #pragma once
 
 #include <QWidget>
-class KLineEdit;
+class QLineEdit;
 namespace KContacts
 {
 class Addressee;
@@ -31,14 +31,14 @@ Q_SIGNALS:
     void organizationChanged(const QString &text);
 
 private:
-    KLineEdit *mOrganizationWidget = nullptr;
-    KLineEdit *mProfessionWidget = nullptr;
-    KLineEdit *mTitleWidget = nullptr;
-    KLineEdit *mDepartmentWidget = nullptr;
-    KLineEdit *mOfficeWidget = nullptr;
-    KLineEdit *mManagerWidget = nullptr;
-    KLineEdit *mAssistantWidget = nullptr;
-    Akonadi::FreeBusyEditWidget *mFreeBusyWidget = nullptr;
-    ImageWidget *mLogoWidget = nullptr;
+    QLineEdit *const mOrganizationWidget;
+    QLineEdit *const mProfessionWidget;
+    QLineEdit *const mTitleWidget;
+    QLineEdit *const mDepartmentWidget;
+    QLineEdit *const mOfficeWidget;
+    QLineEdit *const mManagerWidget;
+    QLineEdit *const mAssistantWidget;
+    Akonadi::FreeBusyEditWidget *const mFreeBusyWidget;
+    ImageWidget *const mLogoWidget;
 };
 }
