@@ -10,6 +10,7 @@
 #include "mailwidget.h"
 #include "editor/generalinfoeditor/mail/mailtypecombobox.h"
 #include "editor/widgets/preferredlineeditwidget.h"
+#include <KLineEditEventHandler>
 #include <KLocalizedString>
 #include <QHBoxLayout>
 #include <QToolButton>
@@ -26,7 +27,7 @@ MailWidget::MailWidget(QWidget *parent)
     layout->setSpacing(0);
     layout->setContentsMargins({});
 
-    mMailEdit->setTrapReturnKey(true);
+    KLineEditEventHandler::catchReturnKey(mMailEdit);
     mMailEdit->setPlaceholderText(i18nc("@info:placeholder", "Add an Email Account"));
     mMailEdit->setObjectName(QLatin1StringView("mailedit"));
     layout->addWidget(mMailEdit);
@@ -62,9 +63,10 @@ void MailWidget::clearWidget()
     mMailType->setCurrentIndex(0);
 }
 
-void MailWidget::updateAddRemoveButton(bool addButtonEnabled)
+void MailWidget::updateAddRemoveButton(bool addButtonEnabled, bool removeButtonEnabled)
 {
     mAddButton->setEnabled(addButtonEnabled);
+    mRemoveButton->setEnabled(removeButtonEnabled);
 }
 
 void MailWidget::setMail(const KContacts::Email &email)
