@@ -11,7 +11,7 @@
 
 #include "akonadi_contact_widgets_private_export.h"
 #include <QWidget>
-class KLineEdit;
+class QLineEdit;
 namespace KContacts
 {
 class Addressee;
@@ -29,6 +29,6 @@ public:
     void setReadOnly(bool readOnly);
 
 private:
-    KLineEdit *mNickName = nullptr;
+    QLineEdit *const mNickName;
 };
 }
