@@ -10,7 +10,7 @@
 
 #include <QWidget>
 class DateEditWidget;
-class KLineEdit;
+class QLineEdit;
 namespace KContacts
 {
 class Addressee;
@@ -29,8 +29,8 @@ public:
     void setReadOnly(bool readOnly);
 
 private:
-    DateEditWidget *mBirthdateWidget = nullptr;
-    DateEditWidget *mAnniversaryWidget = nullptr;
-    KLineEdit *mPartnerWidget = nullptr;
+    DateEditWidget *const mBirthdateWidget;
+    DateEditWidget *const mAnniversaryWidget;
+    QLineEdit *const mPartnerWidget;
 };
 }
